require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

module OpenvasCli
  describe VasConfig do
    after(:each) do
      cfgs = VasConfig.get_all
      
      cfgs.each { |c|
        c.destroy! if c.name =~ /Test_.*/i
      }
    end

    it 'should get all configurations' do
      cfgs = VasConfig.get_all
      
      cfgs.should_not be nil
      cfgs.length.should be > 0
      
      old_name = ""
      cfgs.each { |c| 
        c.should be_valid 
        c.name.should >= old_name
        old_name = c.name
      }
    end
    
    it 'should get all configurations with details' do
      cfgs = VasConfig.get_all(:show_details => true)
      cfgs.should_not be nil
      cfgs.length.should be > 0
      
      cfgs.each { |c|
        c.should have_at_least(1).family unless c.name =~ /empty/i
        c.should have_at_least(1).preference
      }
    end
    
    it 'be able to copy a configuration' do
      cfg = VasConfig.get_all.first

      new_name = "Test_#{Time.now.strftime('%Y-%m-%d_%H:%M:%S')}"
      new_cfg = VasConfig.copy_config(cfg.id, new_name)      
      
      new_cfg.should_not be nil
      new_cfg.id.should_not be cfg.id
      new_cfg.name.should == new_name
            
      new_cfg.destroy!
    end
    
    it 'be able to copy a configuration with a description' do
      cfg = VasConfig.get_all.first
      
      new_name = "Test_#{Time.now.strftime('%Y-%m-%d_%H:%M:%S')}"
      new_comment = "Test Configuration Named #{new_name}"
      new_cfg = VasConfig.copy_config(cfg.id, new_name, new_comment)
      
      new_cfg.should_not be nil
      new_cfg.id.should_not be cfg.id
      new_cfg.name.should == new_name
      new_cfg.comment.should == new_comment

      new_cfg.destroy!
    end
    
    it 'should save a preference if it has been assigned a new value' do
      cfg = VasConfig.get_all[0]
      
      new_cfg = VasConfig.copy_config(cfg.id, "Test_#{Time.now.strftime('%Y-%m-%d_%H:%M:%S')}")
      
      new_cfg.should_not be nil
      new_cfg.id.should_not be cfg.id
      
      pref = new_cfg.preferences.choice
      pref.should_not be nil

      case pref.val_type
      when :text
        pref.value = "NEW VALUE"
      when :boolean
        pref.value = pref.value ? false : true
      when :choice
        pref.value = pref.val_choices[rand(pref.val_choices.count - 1) + 1]
      end
      
      pref.should be_changed
      
      new_cfg.save!
      
      new_cfg = VasConfig.get_all(:id => new_cfg.id, :show_details => true)[0]
      i = new_cfg.preferences.index { |p| p.name == pref.name && p.nvt_id == pref.nvt_id }
      i.should_not be nil
     
      n_pref = new_cfg.preferences[i]
      n_pref.value.should == pref.value
    end
    
    it 'should not throw an exception when trying to pull with an invalid ID' do
      lambda {
        cfg = VasConfig.get_by_id("foo")
        cfg.should be nil
      }.should_not raise_error
    end
  end
end
