require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

module OpenvasCli
  describe VasLscCredential do
    after(:each) do
      all = VasLscCredential.get_all
      
      all.each { |c|
        c.destroy! if c.name =~ /Test_.*/i
      }
    end

    def next_test_name
      "Test_#{Time.now.strftime('%Y-%m-%d_%H:%M:%S')}"
    end
    
    def valid_params
      {
        :name => next_test_name, 
        :login => "FOOBAR", 
        :comment => "Yet another test credential", 
        :password => "thisCanTr3@llyBe1",
        :password_confirmation => "thisCanTr3@llyBe1"
      }
    end

    it 'should require password and confirmation to be the same' do
      cred = VasLscCredential.new(valid_params)
      cred.should be_valid
      
      cred.password_confirmation = "something different"
      cred.should_not be_valid
      
      cred.should have(1).errors
      
      cred.errors[:password].should_not be nil
    end

    it 'should pull all available credentials' do
      all = VasLscCredential.get_all
      all.should_not be nil
      all.each { |c| c.should be_valid }
    end
    
    it 'should create a new lsc_credential' do
      cred = VasLscCredential.new(valid_params)
      cred.save!
      
      cred.id.should_not be nil
      cred.id.should_not be_empty
      
      n_cred = VasLscCredential.get_by_id(cred.id)
      n_cred.should_not be nil
      n_cred.id.should == cred.id
      n_cred.name.should == cred.name
      n_cred.login.should == cred.login
      n_cred.comment.should == cred.comment
    end
    
    it 'should be able to alter a credential' do
      cred = VasLscCredential.new(valid_params)
      cred.save!
      
      n_cred = VasLscCredential.get_by_id(cred.id)
      n_cred.update_attributes(:login => "NOT_FOOBAR")
      n_cred.save!
      
      n_cred.id.should == cred.id
      
      n_cred = VasLscCredential.get_by_id(cred.id)
      n_cred.login.should == "NOT_FOOBAR"
    end
    
    it 'should be able to take an SMB style login name' do
      cred = VasLscCredential.new(valid_params.merge!({:login=>'FOO\\BAR'}))
      cred.save!
      cred.id.should_not be nil
      cred.id.should_not be_empty
      
      n_cred = VasLscCredential.get_by_id(cred.id)
      n_cred.should_not be nil
      n_cred.login.should == 'FOO\\BAR'
    end
    
    it 'should not barf if it is given an invalid ID to pull' do
      lambda {VasLscCredential.get_all(:id => 'foo')}.should_not raise_error
    end
  end
end
