require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

module OpenvasCli
  describe VasPreference do
    it 'should pull all preferences' do
      preferences = VasPreference.get_all
      preferences.should_not be nil
      
      preferences.each { |p|
        p.should be_valid
      }
    end
    
    it 'should pull a single preference by name and nvt_oid' do
      config = VasConfig.get_all.choice
      
      prefs = VasPreference.get_all(:config_id => config.id)
      o_pref = prefs.choice
      while o_pref.nvt_id.empty?
        o_pref = prefs.choice
      end
      o_pref.should_not be nil
    
      
      prefs = VasPreference.get_all(:config_id => config.id, :nvt_oid => o_pref.nvt_id, :name=>o_pref.name)
      prefs.count.should == 1
      
      n_pref = prefs.first
      n_pref.should_not be nil
      
      o_pref.full_name.should == n_pref.full_name
      o_pref.value.should     == n_pref.value
      o_pref.config_id.should == n_pref.config_id
    end
    
    it 'should pull a single preference by name for the global configuration' do
      config = VasConfig.get_all.choice
      
      prefs = VasPreference.get_all(:config_id => config.id)
      o_pref = prefs.choice
      while !o_pref.nvt_id.empty?
        o_pref = prefs.choice
      end
      o_pref.should_not be nil
    
      
      prefs = VasPreference.get_all(:config_id => config.id, :name=>o_pref.name)
      prefs.count.should == 1
      
      n_pref = prefs.first
      n_pref.should_not be nil
      
      o_pref.full_name.should == n_pref.full_name
      o_pref.value.should     == n_pref.value
      o_pref.config_id.should == n_pref.config_id
    end
    
    it 'get_by_name should pull a single preference by name and nvt_oid' do
      config = VasConfig.get_all.choice
      
      prefs = VasPreference.get_all(:config_id => config.id)
      o_pref = prefs.choice
      while o_pref.nvt_id.empty?
        o_pref = prefs.choice
      end
      o_pref.should_not be nil
    
      n_pref = VasPreference.get_by_name(config.id, o_pref.name, o_pref.nvt_id)
      n_pref.should_not be nil
      
      o_pref.full_name.should == n_pref.full_name
      o_pref.value.should     == n_pref.value
      o_pref.config_id.should == n_pref.config_id
    end
    
    it 'get_by_name should pull a single preference by name for the global configuration' do
      config = VasConfig.get_all.choice
      
      prefs = VasPreference.get_all(:config_id => config.id)
      o_pref = prefs.choice
      while !o_pref.nvt_id.empty?
        o_pref = prefs.choice
      end
      o_pref.should_not be nil
      
      n_pref = VasPreference.get_by_name(config.id, o_pref.name)
      n_pref.should_not be nil
      
      o_pref.full_name.should == n_pref.full_name
      o_pref.value.should     == n_pref.value
      o_pref.config_id.should == n_pref.config_id
    end
    
    it 'should pull all preferences for a given configuration' do
      config = VasConfig.get_all.choice
      
      all = VasPreference.get_all(:config_id => config.id)
      all.should_not be_empty
      all.each { |p| p.config_id.should == config.id }
    end
    
    it 'should have an nvt_name if nvt_id exists' do
      config = VasConfig.get_all.choice
      
      all = VasPreference.get_all(:config_id => config.id)
      all.should_not be_empty
      
      all.each { |p| 
        if p.nvt_id && !p.nvt_id.empty?
          p.nvt_name.should_not be nil 
          p.nvt_name.should_not be_empty
        end
      }
    end
    
    it 'should sort by name' do
      config = VasConfig.get_all.choice
      
      all = VasPreference.get_all(:config_id => config.id, :sort_by => :name)
      all.each { |p|
        old_name = p.name unless old_name
        p.name.should >= old_name
        old_name = p.name
      }
    end
    
    it 'should sort by nvt_id' do
      config = VasConfig.get_all.choice
      
      all = VasPreference.get_all(:config_id => config.id, :sort_by => :nvt_id)
      all.each { |p|
        old_id = p.nvt_id unless old_id
        p.nvt_id.should >= old_id
        old_id = p.nvt_id
      }
    end
    
    it 'should sort by nvt_name' do
      config = VasConfig.get_all.choice
      
      all = VasPreference.get_all(:config_id => config.id, :sort_by => :nvt_name)
      all.each { |p|
        old_name = p.nvt_name unless old_name
        p.nvt_name.should >= old_name
        old_name = p.nvt_name
      }
    end
  end
end
