require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')
require 'nokogiri'

module OpenvasCli
  describe VasReport do
    it "should pull all available reports" do
      repts = VasReport.get_all
      
      repts.should_not be nil
      
      repts.each { |r| r.should be_valid }
    end
    
    it 'should pull a raw XML dump for a single report' do
      rept = VasReport.get_all.choice
      
      xml = rept.to_xml
      
      xdoc = Nokogiri::XML(xml) #it should be a valid xml document
      
      xdoc.at_xpath("//report/@id").value.should == rept.id
    end
    
    it 'should pull a specific report by id' do
      o_rept = VasReport.get_all.choice
      o_rept.should_not be nil
      n_rept = VasReport.get_by_id(o_rept.id)
      n_rept.should_not be nil
      
      o_rept.id.should == n_rept.id
    end
    
    it 'should report the associated results' do
      all = VasReport.get_all
      
      all.each { |r|
        r.result_count[:filtered].should == r.results.count
      }
    end
    
    it 'should filter the results' do
      all = VasReport.get_all(:levels => [:high])
      
      all.each { |report|
        report.results.each{ |result|
          result.threat.should =~ /high/i
        }
      }
      
      all = VasReport.get_all(:levels => [:log])
      
      all.each { |report|
        report.results.each{ |result|
          result.threat.should =~ /log/i
        }
      }
      
      all = VasReport.get_all(:levels => [:medium, :debug, :low])
      
      all.each { |report|
        report.results.each{ |result|
          result.threat.should =~ /(medium)|(debug)|(low)/i
        }
      }
    end
    
    it 'should return an empty set when passed a bad report_id' do
      lambda {
        r = VasReport.get_by_id(:id => '0000000000')
        r.should be nil
      }.should_not raise_error
    end
    
    it 'default sort should be by started_at descending' do
      last_date = nil
      VasReport.get_all.each { |r|
        last_date = r.started_at unless last_date
        r.started_at.should <= last_date
        last_date = r.started_at
      }
    end
    
    it 'just adding :sort_order => :ascending should reverse the started_at sort' do
      last_date = nil
      VasReport.get_all(:sort_order => :ascending).each { |r|
        last_date = r.started_at unless last_date
        r.started_at.should >= last_date
        last_date = r.started_at
      }
    end
    
    it 'should sort by task_name (default :descending)' do
      last_name = nil
      VasReport.get_all(:sort => :task_name).each { |r|
        last_name = r.task_name unless last_name
        r.task_name.should <= last_name
        last_date = r.task_name
      }
    end
    
    it 'should sort by :task_name, :ascending' do
      last_name = nil
      VasReport.get_all(:sort => :task_name, :sort_order => :ascending).each { |r|
        last_name = r.task_name unless last_name
        r.task_name.should >= last_name
        last_date = r.task_name
      }
    end
    
    it 'should pull results for a report when the ID and a filter is specified' do
      report_ids = {}
      VasReport.get_all(:levels => [:high, :medium]).each { |r| 
        report_ids[r.id] = r.results.count unless r.results.empty?
      }
      report_ids.each { |id, count|
        options = {
          :sort_order => :descending, 
          :sort       => :started_at, 
          :levels     => [:high, :medium], 
          :id         => id
        }
        rept = VasReport.get_all(options)[0]
        rept.should_not be nil
        rept.should have(count).results
      }
      
    end
  end
end
