require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

module OpenvasCli
  describe VasResult do
    def get_random_result
      VasResult.get_all.choice
    end
  
    it 'should pull all results' do
      all_results = VasResult.get_all 
      
      all_results.should_not be nil
      
      all_results.each { |r| r.should be_valid }
    end
    
    it 'should be able to paginate results', :slow=>true do
      result_count = VasResult.get_all.count
      
      start = 0
      num = 20
      
      while start < result_count do
        results = VasResult.get_all(:start => start, :count => num)
        
        results.count.should <= 20
        
        start += results.count
      end
    end
    
    it 'should sort by threat by default' do
      results = VasResult.get_all
      
      last_val = 9
      results.each { |r|
        r.threat_level.should <= last_val
        last_val = r.threat_level
      }
    end
    
    it 'should sort the results by ID' do
      results = VasResult.get_all(:sort_by => :result_id)
      
      last_id = ""
      results.each { |r|
        r.id.should >= last_id
        last_id = r.id
      }
    end
    
    it 'should sort the results by host' do
      results = VasResult.get_all(:sort_by => :host)
      
      last_host = ""
      results.each { |r|
        r.host.should >= last_host
        last_host = r.host
      }
    end
    
    it 'should sort the results by rule_id' do
      results = VasResult.get_all(:sort_by => :rule_id)
      
      last_val = ""
      results.each { |r|
        r.id.should >= last_val
        last_val = r.id
      }
    end
    
    it 'should sort the results by subnet' do
      results = VasResult.get_all(:sort_by => :subnet)
      
      last_val = ""
      results.each { |r|
        r.subnet.should >= last_val
        last_val = r.subnet
      }
    end
    
    it 'should sort the results by threat' do
      results = VasResult.get_all(:sort_by => :threat)
      
      last_val = 9
      results.each { |r|
        r.threat_level.should <= last_val
        last_val = r.threat_level
      }
    end
    
    it 'shoudl pull results for a specified task' do
      tasks = VasTask.get_all
      
      unless tasks.empty?
        task_id = tasks.choice.id
        results = VasResult.get_all(:task_id => task_id)
        results.each { |r| r.task_id.should == task_id }
        
        all_tasks = VasResult.get_all
        
        all_tasks.count.should >= results.count
      end
    end
    
    it 'should filter based off of threat level' do
      results = VasResult.get_all(:filter=>[:high, :medium])
      threats = ["High", "Medium"]
      results.each { |r|
        threats.should include r.threat
      }
    end
    
    it 'should return null when pulling by task_id' do
      lambda {
        VasResult.get_by_id('foo').should be nil
      }.should_not raise_error
    end
    
    it 'should not raise an error on save!' do
      result = get_random_result
      lambda {
        result.save!
      }.should_not raise_error
    end
    
    it 'should return true on save' do
      result = get_random_result
      result.save.should be true
    end
    
    it 'should not raise an error on destroy!' do
      result = get_random_result
      lambda {
        result.destroy!
      }.should_not raise_error
    end
    
    it 'should return true on save' do
      result = get_random_result
      result.destroy.should be true
    end
    
    it 'should return a result by ID' do
      result = get_random_result
      
      nr = VasResult.get_by_id(result.id)
      nr.should_not be nil
    end
  end
end
