require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')
require 'nokogiri'

module OpenvasCli
  describe XmlAddin do
    class DummyClass
      include XmlAddin
    end
    
    it 'should have the extract_value_from method' do
      DummyClass.public_methods.should include "extract_value_from"
    end
    
    it 'should extract the correct value from a node with only text decendants' do
      bldr = Nokogiri::XML::Builder.new { |x|
        x.base_node { x.text("Test Value") }
      }
      
      DummyClass.extract_value_from("/base_node", bldr.doc).should == "Test Value"
    end
    
    it 'should extract the correct value from a node with a single attribute' do
      bldr = Nokogiri::XML::Builder.new { |x|
        x.base_node({:t_attr => "Test Value"})
      }
      
      DummyClass.extract_value_from("/base_node/@t_attr", bldr.doc).should == "Test Value"
    end
    
    it 'should extract the text value from a node even if it has children' do
      bldr = Nokogiri::XML::Builder.new { |x|
        x.base_node {
          x.child_node_one { x.text "Child 1 Value" }
          x.child_node_two({:ch_one_attr => "Child 2 Value"})
          x.text("Test Value")
        }
      }
      
      DummyClass.extract_value_from("/base_node", bldr.doc).should == "Test Value"
    end
    
  end
end
